Sophie

Sophie

distrib > Mageia > 7 > i586 > media > core-updates-src > by-pkgid > 591df75d59996d7a75226b4b5da6b5f6 > files > 9

virtualbox-6.1.16-4.mga7.src.rpm


 src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp |   14 ++++++----
 1 file changed, 9 insertions(+), 5 deletions(-)

diff -Nurp VirtualBox-6.0.0.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
--- VirtualBox-6.0.0.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp	2018-12-18 14:59:47.000000000 +0200
+++ VirtualBox-6.0.0/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp	2019-01-08 03:13:09.004106909 +0200
@@ -251,15 +251,15 @@ void UINameAndSystemEditor::sltFamilyCha
         if (iIndexWin7 != -1)
             m_pComboType->setCurrentIndex(iIndexWin7);
     }
     /* Or select Oracle Linux item for Linux family as default: */
     else if (m_strFamilyId == "Linux")
     {
-        QString strDefaultID = "Oracle";
+        QString strDefaultID = "Mageia";
         if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
             strDefaultID += "_64";
-        const int iIndexUbuntu = m_pComboType->findData(strDefaultID, TypeID);
-        if (iIndexUbuntu != -1)
-            m_pComboType->setCurrentIndex(iIndexUbuntu);
+        const int iIndexMageia = m_pComboType->findData(strDefaultID, TypeID);
+        if (iIndexMageia != -1)
+            m_pComboType->setCurrentIndex(iIndexMageia);
     }
     /* Else simply select the first one present: */
     else
@@ -468,6 +468,10 @@ void UINameAndSystemEditor::prepareFamil
 
     /* Choose the 1st item to be the current: */
     m_pComboFamily->setCurrentIndex(0);
+    /* Default to Linux */
+    const int liIndex = m_pComboFamily->findData("Linux", TypeID);
+    if (liIndex != -1)
+        m_pComboFamily->setCurrentIndex(liIndex);
     /* And update the linked widgets accordingly: */
     sltFamilyChanged(m_pComboFamily->currentIndex());
 }
@@ -251,15 +251,15 @@ void UINameAndSystemEditor::sltFamilyCha
             m_pComboType->setCurrentIndex(iIndexWin7);
     }
-    /* Or select Oracle Linux item for Linux family as default: */
+    /* Or select Mageia Linux item for Linux family as default: */
     else if (m_strFamilyId == "Linux")
     {